<?php
/*
Plugin Name:Disable Checkout For Specific Email Addresses For WooCommerce
Plugin URI: https://qwebmaster.com/disable-checkout-for-specific-email-addresses-for-woocommerce
Description: This plugin allows you to easily disable checkout for customers with specific email addresses. Add one or multiple email addresses in the plugin's settings page and if the email address checking out matches one on the list, the checkout will be disabled and a WooCommerce notice will be displayed to the user.
Version: 1.1.1
WC requires at least: 4.0
WC tested up to: 9.0.0
Author: Qwebmaster
Author URI: https://qwebmaster.com/
Copyright: © 2023 Qwebmaster
License:         GNU General Public License v3.0
License URI:     http://www.gnu.org/licenses/gpl-3.0.html
*/

add_action('admin_menu', 'qweb_dcfsea_menu');
function qweb_dcfsea_menu() {
    // Check if WooCommerce is active and add submenu
    if (class_exists('WooCommerce')) {
        add_submenu_page(
            'woocommerce', // Slug of the parent menu (WooCommerce)
            'Disable Checkout For Email Address', // Page title
            'Disable Checkout For Email Address', // Menu title
            'manage_options', // Capability
            'qweb_dcfsea', // Menu slug
            'qweb_dcfsea_options' // Function that displays the options page
        );
    }
}

function qweb_dcfsea_options() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.'));
    }

    // Save options if the user submitted the form
    if (isset($_POST['qweb_dcfsea_emails']) && isset($_POST['qweb_dcfsea_msg'])) {
        // Sanitize and update the options
        update_option('qweb_dcfsea_emails', sanitize_text_field($_POST['qweb_dcfsea_emails']));
        update_option('qweb_dcfsea_msg', sanitize_text_field($_POST['qweb_dcfsea_msg']));
        // Admin notice for confirmation
        echo '<div class="updated"><p>Settings updated.</p></div>';
    }

    $qweb_dcfsea_emails = get_option('qweb_dcfsea_emails');
    $qweb_dcfsea_msg = get_option('qweb_dcfsea_msg');
    ?>

    <div class="wrap">
        <h2>Disable Checkout For Specific Email Addresses For WooCommerce</h2>
        <form method="post" action="">
            <?php settings_fields('qweb_dcfsea_options'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Email Addresses</th>
                    <td>
                        <textarea name="qweb_dcfsea_emails" rows="10" cols="50" type="textarea"><?php echo esc_textarea($qweb_dcfsea_emails); ?></textarea>
                        <br />Enter one or multiple email addresses separated by a comma.
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Message</th>
                    <td>
                        <textarea name="qweb_dcfsea_msg" rows="10" cols="50" type="textarea"><?php echo esc_textarea($qweb_dcfsea_msg); ?></textarea>
                        <br />Enter the message that will be displayed to the customer when checkout is disabled.
                    </td>
                </tr>
            </table>
            <p class="submit">
                <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
            </p>
        </form>
    </div>
    <?php
}



add_action('woocommerce_checkout_process', 'qweb_dcfsea_check');

function qweb_dcfsea_check() {
    // Retrieve the posted email address from the checkout form
    $posted_email = strtolower(trim($_POST['billing_email']));

    // Retrieve the disallowed email addresses and process them
    $disallowed_emails = array_map('strtolower', array_map('trim', explode(',', get_option('qweb_dcfsea_emails'))));

    // Check if the posted email is in the list of disallowed emails
    if (in_array($posted_email, $disallowed_emails)) {
        // Retrieve the custom message set in the options
        $qweb_dcfsea_msg = get_option('qweb_dcfsea_msg');
        // Throw an error and prevent checkout
        wc_add_notice($qweb_dcfsea_msg, 'error');
    }
}


?>
